==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/boitesdialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef BOITESDIALOG_H
#define BOITESSDIALOG_H

#include "ui_boitesdialog.h"
#include "highlighter.h"
#include "pdfviewer.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QProgressDialog>

class BoitesDialog : public QDialog  {
   Q_OBJECT
public:
	BoitesDialog(QWidget *parent=0);
	~BoitesDialog();
	Ui::BoitesDialog ui;
QString pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
QColor couleurSupp1,couleurSupp2,couleurSupp3;

private :
QStringList expressionList, couleurList, styleList;
QString asyMessage;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<QProcess> asy_pdf_proc;
bool estModifie, existvaleur, erreurProcessus;
Highlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
QPointer<QProgressDialog> progressDialog;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActiverBoites(bool etat);
void ActiverAxes(bool etat);
void ActiverGrille(bool etat);

QString GenererCode();
void AfficherCode();
void ajouterBoite();
void supprimerBoite();
void actualiserExpression();
void actualiserCouleur();
void actualiserStyle();
void actualiserItemInfo();
int numeroItem();
void NouvelleBoite();
void SauverBoite();
void ChargerBoite();

void AsyPdfTemp();
void finAsyPdfProcess(int err);
void VoirTemp();
void readInfoOutput();

void NettoyerCode();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};


#endif

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/boitesdialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#ifndef BOITESDIALOG_H
#define BOITESSDIALOG_H

#include "ui_boitesdialog.h"
#include "highlighter.h"
#include "pdfviewer.h"
#include "cmdlauncher.h"


#include <QPointer>
#include <QCloseEvent>


class BoitesDialog : public QDialog  {
   Q_OBJECT
public:
	BoitesDialog(QWidget *parent=0);
	~BoitesDialog();
	Ui::BoitesDialog ui;
QString extraPath, pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier, preambuleAsy;
QColor couleurSupp1,couleurSupp2,couleurSupp3;

private :
QStringList expressionList, couleurList, styleList;
QString tempDir,asyTempFile,pdfTempFile,prefixFile;
QPointer<CmdLauncher> asy_pdf_proc;
bool estModifie, existvaleur, erreurProcessus;
Highlighter *highlighterSupp;
QPointer<PdfViewer> pdfviewerWindow;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActiverBoites(bool etat);
void ActiverAxes(bool etat);
void ActiverGrille(bool etat);

QString GenererCode();
void AfficherCode();
void ajouterBoite();
void supprimerBoite();
void actualiserExpression();
void actualiserCouleur();
void actualiserStyle();
void actualiserItemInfo();
int numeroItem();
void NouvelleBoite();
void SauverBoite();
void ChargerBoite();

void AsyPdfTemp();
void VoirTemp();
void ErreurCompilation();

void NettoyerCode();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void asy_pdf_fini();
};


#endif
